Move to new association interface

A new association interface is defined in phosphor-dbus-interfaces
It would be nice to move the local version of the interface
to the new one.

The behavior of how association work is described here:
https://github.com/openbmc/docs/blob/master/object-mapper.md#associations

Partially resolves openbmc/openbmc#3584

Tested: Create a new log using the Create interface, see that
org.openbmc.Associations has been replaced by the xyz one and
2 association objects are created by the mapper.

Signed-off-by: John Wang <wangzqbj@inspur.com>
Change-Id: I9bcddd4765b12224967383bab2dbaa6d273e2790
diff --git a/elog_entry.hpp b/elog_entry.hpp
index abcfe50..9c93afe 100644
--- a/elog_entry.hpp
+++ b/elog_entry.hpp
@@ -1,12 +1,12 @@
 #pragma once
 
-#include "org/openbmc/Associations/server.hpp"
 #include "xyz/openbmc_project/Logging/Entry/server.hpp"
 #include "xyz/openbmc_project/Object/Delete/server.hpp"
 #include "xyz/openbmc_project/Software/Version/server.hpp"
 
 #include <sdbusplus/bus.hpp>
 #include <sdbusplus/server/object.hpp>
+#include <xyz/openbmc_project/Association/Definitions/server.hpp>
 
 namespace phosphor
 {
@@ -16,7 +16,7 @@
 using EntryIfaces = sdbusplus::server::object::object<
     sdbusplus::xyz::openbmc_project::Logging::server::Entry,
     sdbusplus::xyz::openbmc_project::Object::server::Delete,
-    sdbusplus::org::openbmc::server::Associations,
+    sdbusplus::xyz::openbmc_project::Association::server::Definitions,
     sdbusplus::xyz::openbmc_project::Software::server::Version>;
 
 using AssociationList =
@@ -31,7 +31,7 @@
  *  @brief OpenBMC logging entry implementation.
  *  @details A concrete implementation for the
  *  xyz.openbmc_project.Logging.Entry and
  *  org.openbmc.Associations DBus APIs.
  */
 class Entry : public EntryIfaces
 {
@@ -31,7 +31,7 @@
  *  @details A concrete implementation for the
  *  xyz.openbmc_project.Logging.Entry and
- *  org.openbmc.Associations DBus APIs.
+ *  xyz.openbmc_project.Associations.Definitions DBus APIs.
  */
 class Entry : public EntryIfaces